/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*- */

#include "framecpp/Common/MemoryBuffer.hh"

namespace FrameCPP
{
  namespace Common
  {
    //===================================================================
    //-------------------------------------------------------------------
    /// 
    //-------------------------------------------------------------------
    MemoryBuffer::Seeder::
    Seeder( )
    {
    }

    
    void MemoryBuffer::Seeder::
    operator( )( buffer_type& Buffer )
    {
      output = &Buffer;
    }

    //===================================================================
    //-------------------------------------------------------------------
    /// 
    //-------------------------------------------------------------------
    
    MemoryBuffer::BufferSeeder::
    BufferSeeder( )
    {
    }

    bool MemoryBuffer::BufferSeeder::
    operator( )( void )
    {
      return false;
    }

    //===================================================================
    //-------------------------------------------------------------------
    /// The default constructor will initialize all the parts used
    /// in the general case.
    //-------------------------------------------------------------------
    MemoryBuffer::
    MemoryBuffer( std::ios::openmode Mode,
                  bool ParentAutoDelete )
      : buffer_type( Mode ),
        buffer_user_supplied(false)
    {
      AutoDelete( ParentAutoDelete );
    }

    //-------------------------------------------------------------------
    /// The default constructor will initialize all the parts used
    /// in the general case.
    //-------------------------------------------------------------------
    MemoryBuffer::
    MemoryBuffer( Seeder& Seed,
                  bool ParentAutoDelete )
      : buffer_type( std::ios::in )
    {
      Seed( *this );	// Give the seed routine the destination buffer
      while ( Seed( ) ) // Process input till have a full frame file
      {
        ;
      }
      AutoDelete( ParentAutoDelete );
    }

    //-------------------------------------------------------------------
    /// Be careful to release all the resources that were created
    /// for this object.
    //-------------------------------------------------------------------
    MemoryBuffer::
    ~MemoryBuffer( )
    {
    }

    //-------------------------------------------------------------------
    /// Filtering currently is not optimized at the this layer so
    /// this method will always return false.
    //-------------------------------------------------------------------
    bool MemoryBuffer::
    FilterInternally( ) const
    {
      return false;
    }

    std::string MemoryBuffer::
    str( )
    {
      return buffer_type::str( );
    }

    void MemoryBuffer::
    str( const std::string& S )
    {
      buffer_user_supplied = true;
      buffer_type::str( S );
    }

    MemoryBuffer* MemoryBuffer::
    setbuf( char_type* S, std::streamsize N )
    {
      if ( N != std::streamsize( M_BUFFER_SIZE_SYSTEM ) )
      {
	buffer_user_supplied = true;
        buffer_type::setbuf( S, N );
      }
      return this;
    }

    void MemoryBuffer::
    buffer( )
    {
      //-----------------------------------------------------------------
      // There is no special initialization that needs to happen
      //-----------------------------------------------------------------
      if ( buffer_user_supplied == false )
      {
	//---------------------------------------------------------------
	// Allocation of the default buffer
	//---------------------------------------------------------------
	buffer_cache.reset( new char_type[ M_BUFFER_SIZE_DEFAULT ] );
	buffer_type::setbuf(buffer_cache.get( ), M_BUFFER_SIZE_DEFAULT );
      }
    }

    //-------------------------------------------------------------------
    /// \brief Perform filtering operations on the stream
    //-------------------------------------------------------------------
    void MemoryBuffer::
    filter( const char_type* Begin,
            const char_type* End )
    {
      std::cerr << "DEBUG:MemoryBuffer::filter:"
                << " Begin: " << (void*)Begin
                << " End: " << (void*)End
                << std::endl
        ;
    }

  } // namespace Common

} // namespace FrameCPP
